@@ -16,7 +16,7 @@ from flask_bootstrap import SwitchField
 class UserAdmin(AdminLTEModelView):
     
     list_template = 'model/user_list.html'    
-    form_excluded_columns=['last_reset_time']
+    # form_excluded_columns=['last_reset_time']
     # edit_modal=True
     # create_modal=True
     # column_display_pk = True
@@ -61,6 +61,7 @@ class UserAdmin(AdminLTEModelView):
         # name=_'just for remembering',
         # usage_limit_GB="in GB",
         # current_usage_GB="in GB"
+        last_reset_time=_("If monthly is enabled, the usage will be reset after 30 days from this date.")
     )
     column_editable_list=["usage_limit_GB","current_usage_GB","expiry_time"]
     # form_extra_fields={
@@ -77,13 +78,13 @@ class UserAdmin(AdminLTEModelView):
         proxy_path=hconfig(ConfigEnum.proxy_path)
         d=Domain.query.filter(Domain.mode!=DomainType.fake).first()
         if d:
-            link=f"<a target='_blank' href='https://{d.domain}/{proxy_path}/{model.uuid}/multi'><i class='fa-solid fa-arrow-up-right-from-square'></i> {model.name}</a>"
+            link=f"<a target='_blank' href='https://{d.domain}/{proxy_path}/{model.uuid}/new'><i class='fa-solid fa-arrow-up-right-from-square'></i> {model.name}</a>"
             return Markup(link)
         else:
             return model.name
     def _ul_formatter(view, context, model, name):
         
-        return Markup(" ".join([hiddify.get_user_link(model.uuid,d,'multi') for d in Domain.query.filter(Domain.mode!=DomainType.fake).all()]))
+        return Markup(" ".join([hiddify.get_user_link(model.uuid,d,'new') for d in Domain.query.filter(Domain.mode!=DomainType.fake).all()]))
     def _uuid_formatter(view, context, model, name):
         return Markup(f"<span>{model.uuid}</span>")
     def _usage_formatter(view, context, model, name):
