@@ -54,7 +54,7 @@ def init_app(app):
         except:
             # raise PermissionError("Invalid secret")
             abort(400,'invalid user')
-        g.is_admin = f'{g.user_uuid}'==hconfig(ConfigEnum.admin_secret)
+        g.is_admin = g.user_uuid==uuid.UUID(hconfig(ConfigEnum.admin_secret))
         
         if not g.is_admin:
             g.user=User.query.filter(User.uuid==f'{g.user_uuid}').first()
